summary refs log tree commit diff
path: root/pkgs/applications/misc/gramps/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/applications/misc/gramps/default.nix')
-rw-r--r--pkgs/applications/misc/gramps/default.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkgs/applications/misc/gramps/default.nix b/pkgs/applications/misc/gramps/default.nix
index 31cdb8d17863..79393eee7f11 100644
--- a/pkgs/applications/misc/gramps/default.nix
+++ b/pkgs/applications/misc/gramps/default.nix
@@ -1,7 +1,7 @@
 { stdenv, fetchurl, gtk3, pythonPackages, python, pycairo, pygobject3, intltool,
   pango, gsettings_desktop_schemas }:
 
-pythonPackages.buildPythonPackage rec {
+pythonPackages.buildPythonApplication rec {
   version = "4.1.1";
   name = "gramps-${version}";
   namePrefix = "";
@@ -18,7 +18,7 @@ pythonPackages.buildPythonPackage rec {
 
   pythonPath = [ pygobject3 pango pycairo pythonPackages.bsddb ];
 
   # Same installPhase as in buildPythonPackage but without --old-and-unmanageble
   # install flag.
   installPhase = ''
     runHook preInstall
@@ -18,7 +18,7 @@ pythonPackages.buildPythonPackage rec {
   pythonPath = [ pygobject3 pango pycairo pythonPackages.bsddb ];
 
-  # Same installPhase as in buildPythonPackage but without --old-and-unmanageble
+  # Same installPhase as in buildPythonApplication but without --old-and-unmanageble
   # install flag.
   installPhase = ''